==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/DestinationRuleListBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class DestinationRuleListBuilder extends DestinationRuleListFluentImpl<DestinationRuleListBuilder> implements VisitableBuilder<DestinationRuleList,DestinationRuleListBuilder>{
  public DestinationRuleListBuilder() {
    this(false);
  }
  public DestinationRuleListBuilder(Boolean validationEnabled) {
    this(new DestinationRuleList(), validationEnabled);
  }
  public DestinationRuleListBuilder(DestinationRuleListFluent<?> fluent) {
    this(fluent, false);
  }
  public DestinationRuleListBuilder(DestinationRuleListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new DestinationRuleList(), validationEnabled);
  }
  public DestinationRuleListBuilder(DestinationRuleListFluent<?> fluent,DestinationRuleList instance) {
    this(fluent, instance, false);
  }
  public DestinationRuleListBuilder(DestinationRuleListFluent<?> fluent,DestinationRuleList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  public DestinationRuleListBuilder(DestinationRuleList instance) {
    this(instance,false);
  }
  public DestinationRuleListBuilder(DestinationRuleList instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  DestinationRuleListFluent<?> fluent;
  Boolean validationEnabled;
  public DestinationRuleList build() {
    DestinationRuleList buildable = new DestinationRuleList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  
}

==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/DestinationRuleListBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class DestinationRuleListBuilder extends DestinationRuleListFluent<DestinationRuleListBuilder> implements VisitableBuilder<DestinationRuleList,DestinationRuleListBuilder>{
  public DestinationRuleListBuilder() {
    this(false);
  }
  public DestinationRuleListBuilder(Boolean validationEnabled) {
    this(new DestinationRuleList(), validationEnabled);
  }
  public DestinationRuleListBuilder(DestinationRuleListFluent<?> fluent) {
    this(fluent, false);
  }
  public DestinationRuleListBuilder(DestinationRuleListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new DestinationRuleList(), validationEnabled);
  }
  public DestinationRuleListBuilder(DestinationRuleListFluent<?> fluent,DestinationRuleList instance) {
    this(fluent, instance, false);
  }
  public DestinationRuleListBuilder(DestinationRuleListFluent<?> fluent,DestinationRuleList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new DestinationRuleList());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  public DestinationRuleListBuilder(DestinationRuleList instance) {
    this(instance,false);
  }
  public DestinationRuleListBuilder(DestinationRuleList instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new DestinationRuleList());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  DestinationRuleListFluent<?> fluent;
  Boolean validationEnabled;
  public DestinationRuleList build() {
    DestinationRuleList buildable = new DestinationRuleList(fluent.getApiVersion(),fluent.buildItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  
}
